import React, { useState, useEffect } from "react";
import {
  ScrollView,
  StyleSheet,
  Text,
  View,
  Image,
  StatusBar,
  TouchableOpacity,
  Dimensions,
} from "react-native";
import { SCREEN_WIDTH, SCREEN_HEIGHT, SELFI_IMAGE } from "../common/Constants";
import Colors from "../common/Colors";
import { RNCamera } from "react-native-camera";
``;
import Icon from "react-native-vector-icons/FontAwesome";
import { SafeAreaView } from "react-native-safe-area-context";

const crossMark = require("../common/Image/not_blur.png");

const Camera = ({ navigation, route }) => {
  const [cameraState, SetCameraState] = useState("");
  const [staincil, SetStaincil] = useState("");
  const [date, SetDate] = useState("");
  const [flashState, SetFlashState] = useState(false);
  const [screenHeight, SetScreenHeight] = useState(SCREEN_HEIGHT);
  const [screenWidth, SetScreenWidth] = useState(SCREEN_WIDTH);

  const { title, stepStencilAssests } = route.params;
  useEffect(() => {
    changeCameraState();
  }, []);

  const onLayoutChange = () => {
    SetScreenHeight(Dimensions.get("window").height),
      SetScreenWidth(Dimensions.get("window").width);
  };
  const changeCameraState = () => {
    if (title == SELFI_IMAGE) {
      SetCameraState(RNCamera.Constants.Type.front);
      SetStaincil(stepStencilAssests);
    } else {
      SetCameraState(RNCamera.Constants.Type.back);
      SetStaincil(stepStencilAssests);
    }
  };

  const takePicture = async function (camera) {
    const options = { quality: 0.2, base64: true };
    const data = await camera.takePictureAsync(options);
    //  eslint-disable-next-line

    // this.setState({
    //     localPath: data.uri,
    //     cameraData: data,
    // })

    //path of photo

    console.log(JSON.stringify(data, null, "  ")); //path of photo
    // this.watermarkLocation()
    //Date calulation for the display on preciew Screen
    const date = new Date().getDate();
    const month = new Date().getMonth() + 1;
    const year = new Date().getFullYear();

    //Time calulation for the display on preciew Screen
    const hour = new Date().getHours();
    const minute = new Date().getMinutes();
    const seconds = new Date().getSeconds();
    //Alert.alert(date + '-' + month + '-' + year);
    // You can turn it in to your desired format
    SetDate(
      date +
        "-" +
        month +
        "-" +
        year +
        "  " +
        hour +
        ":" +
        minute +
        ":" +
        seconds
    );
  };

  const toggleTorch = () => {
    if (flashState == true) {
      SetFlashState(false);
    } else {
      SetFlashState(true);
    }
  };
  return (
    <SafeAreaView onLayout={onLayoutChange.bind(this)}>
      <View style={styles.container}>
        <StatusBar hidden={true} />
        <RNCamera
          style={styles.preview}
          type={cameraState}
          flashMode={
            flashState
              ? RNCamera.Constants.FlashMode.auto
              : RNCamera.Constants.FlashMode.off
          }
          androidCameraPermissionOptions={{
            title: "Permission to use camera",
            message: "We need your permission to use your camera",
            buttonPositive: "Ok",
            buttonNegative: "Cancel",
          }}
          androidRecordAudioPermissionOptions={{
            title: "Permission to use audio recording",
            message: "We need your permission to use your audio",
            buttonPositive: "Ok",
            buttonNegative: "Cancel",
          }}
          // pausePreview={true}
          // pauseAfterCapture={true}
          autoFocus={true}
        >
          {({ camera, status, recordAudioPermissionStatus }) => {
            // if (status !== 'READY') return <PendingView />;
            return (
              <View
                style={{
                  flex: 1,
                  position: "absolute",
                  width: SCREEN_WIDTH,
                  height: SCREEN_HEIGHT,
                }}
              >
                <Image
                  source={crossMark}
                  style={{
                    width: 50,
                    height: 50,
                    position: "absolute",
                    left: 1,
                  }}
                />
                <Image
                  source={crossMark}
                  style={{
                    width: 50,
                    height: 50,
                    position: "absolute",
                    left: 1,
                    bottom: 1,
                  }}
                />
                <Image
                  source={crossMark}
                  style={{
                    width: 50,
                    height: 50,
                    position: "absolute",
                    right: 1,
                    bottom: 1,
                  }}
                />
                <Image
                  source={crossMark}
                  style={{
                    width: 50,
                    height: 50,
                    position: "absolute",
                    right: 1,
                  }}
                />

                <Image
                  source={{ uri: staincil }}
                  style={{
                    width: SCREEN_WIDTH - 50,
                    height: SCREEN_HEIGHT,
                    position: "absolute",
                    marginRight: 15,
                    marginLeft: 15,
                    resizeMode: "contain",
                  }}
                />
                <View style={{ flex: 1 }}>
                  <View style={{ flex: 0.5, justifyContent: "flex-end" }}>
                    <TouchableOpacity
                      onPress={() => [takePicture(camera)]}
                      style={styles.capture}
                    >
                      <Icon name="camera" />
                    </TouchableOpacity>
                  </View>
                  <View style={{ flex: 0.5 }}>
                    <TouchableOpacity
                      onPress={() => [toggleTorch()]}
                      style={styles.flash}
                    >
                      <Icon name="flash" />
                    </TouchableOpacity>
                  </View>
                </View>
              </View>
            );
          }}
        </RNCamera>
      </View>
    </SafeAreaView>
  );
};
const styles = StyleSheet.create({
  main: {
    flex: 1,
    flexDirection: "row",
  },
  productImageView: {
    flex: 0.475,
  },
  blankView: {
    flex: 0.05,
  },
  productInfoView: {
    flex: 0.475,
    marginRight: 16,
    width: SCREEN_WIDTH,
    height: SCREEN_HEIGHT,
  },
  headerView: {
    backgroundColor: "#C6AFFF",
    height: 40,
    justifyContent: "center",
  },
  headerText: {
    marginLeft: 16,
    fontSize: 20,
    fontFamily: "Muli-Black",
  },
  productImageStyle: {
    marginTop: 8,
    marginLeft: 16,
    marginBottom: 40,
    height: SCREEN_HEIGHT - 70,
  },
  backButtonImageStyle: {
    marginLeft: 32,
    height: 24,
    width: 24,
    backgroundColor: "red",
  },
  subHeaderText: {
    fontFamily: "Mulli-Regular",
    fontSize: 16,
    marginLeft: 16,
  },
  instructionText: {
    fontFamily: "Mulli-Regular",
    fontSize: 16,
    marginLeft: 16,
    marginBottom: 20,
  },
  captureImageButtonView: {
    height: 48,
    borderRadius: 4,
    backgroundColor: Colors.digitYellow,
    marginTop: 2,
    flexDirection: "row",
    justifyContent: "center",
  },
  captureImageButtonText: {
    fontSize: 16,
    fontFamily: "Muli-Black",
    alignSelf: "center",
  },
  container: {
    flex: 1,
    // flexDirection: 'row',
    // backgroundColor: 'black',
  },
  preview: {
    flex: 1,
    justifyContent: "flex-end",
    alignItems: "center",
  },
  capture: {
    flex: 0,
    backgroundColor: "#fff",
    borderRadius: 5,
    padding: 15,
    paddingHorizontal: 20,
    alignSelf: "flex-end",
    margin: 20,
    position: "absolute",
  },
  flash: {
    flex: 0,
    backgroundColor: "#fff",
    borderRadius: 5,
    padding: 15,
    paddingHorizontal: 20,
    alignSelf: "flex-end",
    margin: 20,
    position: "absolute",
  },
  previewImageStyle: {
    width: SCREEN_WIDTH,
    height: SCREEN_HEIGHT,
  },
  dateAndTimeText: {
    position: "absolute",
    fontSize: 20,
    color: Colors.digitYellow,
    left: 1,
    bottom: 1,
  },
  previewImageIconMainView: {
    flex: 0.05,
    backgroundColor: "black",
  },
  tickMarkImageView: {
    flex: 0.6,
    justifyContent: "flex-end",
  },
  tickMarkImageStyle: {
    width: 30,
    height: 30,
    backgroundColor: "white",
    alignContent: "flex-end",
    marginBottom: 20,
  },
  crossImageView: {
    flex: 0.4,
    justifyContent: "flex-end",
    marginBottom: 20,
  },
  crossImageStyle: {
    width: 30,
    height: 30,
    backgroundColor: "white",
    alignContent: "flex-end",
  },
  cameraIconView: {
    flexDirection: "row",
    justifyContent: "center",
    width: SCREEN_WIDTH,
    position: "absolute",
  },
  infoScrollView: {
    marginTop: 40,
    height: SCREEN_HEIGHT - 200,
  },
  subHeaderTextView: {
    height: 40,
    marginTop: 8,
  },
  backButtonImageView: {
    backgroundColor: "#C6AFFF",
    height: 40,
    justifyContent: "center",
    marginLeft: 16,
  },
  latLongText: {
    position: "absolute",
    fontSize: 20,
    color: Colors.digitYellow,
    left: 1,
  },
  digitEdgeText: {
    position: "absolute",
    fontSize: 20,
    color: Colors.digitYellow,
    right: 1,
  },
});
export default Camera;
